import EventEmitter from "eventemitter3";
import type { DownloadProgressData, DownloadResumable } from "expo-file-system";
import { IFileSystem } from "./interfaces/IFileSystem";
import { IStorage } from "./interfaces/IStorage";
import { DownloadItem, DOWNLOAD_STATUS, Playlist, PlaylistStatus } from "./Playlist";
export { DOWNLOAD_STATUS };
export type { DownloadItem };
export declare const EVENTS: {
    CHANGE: string;
    PROGRESS: string;
    ACTION_COMPLETE: string;
};
export declare type DownloadManagerStatus = PlaylistStatus & {
    totalBytesAvailable: number;
};
export declare type DownloadManagerOptions = {
    downloadDirectory?: string;
    storageKey?: string;
    parallelDownloadCount?: number;
    platform?: string;
    onFatalError?: (error: Error) => void;
};
export declare type PlaylistAction = {
    type: "setPlaylist";
    items: string[];
    id: string;
} | {
    type: "download";
    id: string;
} | {
    type: "pause";
    id: string;
} | {
    type: "delete";
    id: string;
};
export declare class DownloadManager {
    storage: IStorage;
    fileSystem: IFileSystem;
    storageKey: string;
    parallelDownloadCount: number;
    didSetPlaylist: boolean;
    _playlist: Playlist;
    _platform?: string;
    _onFatalError?: (error: Error) => void;
    constructor(storage: IStorage, fileSystem: IFileSystem, options?: DownloadManagerOptions);
    get didRestore(): Promise<void>;
    get ready(): boolean;
    _playlistAction: PlaylistAction | undefined;
    _playlistActionQueue: PlaylistAction[];
    /**
     * Add a new playlist action to the queue
     */
    _addPlaylistAction(action: PlaylistAction): void;
    /**
     * Starting the queue if it hasn't already started
     */
    _runPlaylistActionQueue(): Promise<void>;
    _runNextPlaylistAction(): Promise<void>;
    _setPlaylist(items: string[]): Promise<void>;
    _start(): Promise<void>;
    _pause(): Promise<void>;
    _delete(): Promise<void>;
    _awaitAction(action: PlaylistAction): Promise<PlaylistAction>;
    setPlaylist(items: string[]): Promise<PlaylistAction>;
    start(): Promise<PlaylistAction>;
    pause(): Promise<PlaylistAction>;
    delete(): Promise<PlaylistAction>;
    on(event: any, fn: EventEmitter.ListenerFn, context?: any): {
        remove: () => void;
    };
    removeListener(event: any, fn: EventEmitter.ListenerFn, context?: any): EventEmitter<string | symbol, any>;
    /**
     * Get the status of the initial playlist restored from storage
     */
    getRestoredStatus(): PlaylistStatus;
    /**
     * Get the status of the current playlist
     */
    getStatus(): DownloadManagerStatus;
    getSummary(): string;
    startFile(item: string): Promise<void>;
    _startFile(item: string): Promise<void>;
    pauseFile(item: string): Promise<void>;
    deleteFile(item: string): Promise<void>;
    _getNextItemToDownload(): string | undefined;
    _createResumableDownloadForItem(item: string): DownloadResumable;
    _handleProgress: (uri: string, downloadProgress: DownloadProgressData) => void;
    _emitter: EventEmitter<string | symbol, any>;
    _updateTotalBytesAvailable(): Promise<void>;
}
