import type { DownloadResumable, DownloadPauseState } from "expo-file-system";
import { IFileSystem } from "./interfaces/IFileSystem";
import { IStorage } from "./interfaces/IStorage";
export declare enum DOWNLOAD_STATUS {
    NOT_STARTED = "NOT_STARTED",
    IN_PROGRESS = "IN_PROGRESS",
    PAUSED = "PAUSED",
    COMPLETED = "COMPLETED",
    FAILED = "FAILED"
}
export declare type DownloadItemMetadata = {
    downloadStatus: DOWNLOAD_STATUS;
    fileUri?: string;
    progress?: number;
    totalBytesWritten?: number;
    totalBytesExpectedToWrite?: number;
    savedDownload?: DownloadPauseState;
};
export declare type DownloadItemSource = {
    sourceUri: string;
};
export declare type DownloadItem = DownloadItemMetadata & DownloadItemSource;
declare type PlaylistMetadata = {
    [key: string]: DownloadItemMetadata;
};
export declare function getDocumentPaths(fileSystem: IFileSystem, directory: string): Promise<string[]>;
export declare const DEFAULT_STORAGE_KEY = "downloadManagerMetadata";
export declare const DEFAULT_DOWNLOAD_DIRECTORY = "react-native-file-downloader";
export declare type PlaylistStatus = {
    files: DownloadItem[];
    status: DOWNLOAD_STATUS;
    progress?: number;
};
declare type PlaylistOptions = {
    storageKey?: string;
    platform?: string;
    downloadDirectory?: string;
};
export declare class Playlist {
    items: string[];
    storageKey: string;
    storage: IStorage;
    fileSystem: IFileSystem;
    ready: boolean;
    didSetItems: boolean;
    didRestore: Promise<void>;
    _platform?: string;
    _downloadDirectory: string;
    metadata: PlaylistMetadata;
    initialMetadata: PlaylistMetadata;
    resumableDownloads: {
        [key: string]: DownloadResumable;
    };
    constructor(items: string[] | undefined, storage: IStorage, fileSystem: IFileSystem, options?: PlaylistOptions);
    hasItem(item: string): boolean;
    setItems(items: string[]): void;
    _setItems(items: string[]): void;
    _ensureMetadataForItems(): void;
    getItemsWithDownloadStatus(downloadStatus: DOWNLOAD_STATUS): string[];
    setDownloadStatus(item: string, downloadStatus: DOWNLOAD_STATUS): void;
    getDownloadStatus(item: string): DOWNLOAD_STATUS;
    getMetadata(item: string): DownloadItemMetadata;
    setMetadata(item: string, metadata: DownloadItemMetadata): void;
    getResumableDownload(item: string): DownloadResumable | undefined;
    setResumableDownload(item: string, resumableDownload: DownloadResumable | undefined): void;
    restore(): Promise<void>;
    save(): Promise<void>;
    getCurrentFileUris(): string[];
    deleteUnusedFiles(): Promise<void>;
    _getStatus(downloadItems: DownloadItem[]): PlaylistStatus;
    /**
     * Get the status of the initial playlist restored from storage
     */
    getRestoredStatus(): PlaylistStatus;
    /**
     * Get the status of the current playlist
     */
    getStatus(): PlaylistStatus;
}
export {};
